Beeradvocatereviews
===================

| Beeradvocatereviews is a module that lets you export a user's reviews
| from Beer Advocate.

Usage is very simple. To install:

::

    pip install beeradvocatereviews

To run

::

    beeradvocatereviews MyUsername NumberOfReviewsIHave

e.g.

::

    beeradvocatereviews TheHefe 231
